==> 0.1.2.tar.gz: lib/boppo_easy_permissions.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

import 'permission_constants.dart';

///
/// [requestCode] [BoppoEasyPermissions.request]
/// [perms] [BoppoEasyPermissions.request]
/// [permsGroup] [BoppoEasyPermissions.request]
///
typedef Granted = void Function(
    int requestCode, List<Permissions> perms, PermissionGroup perm);

///
/// [isPermanent]
///
typedef Denied = void Function(int requestCode, List<Permissions> perms,
    PermissionGroup perm, bool isPermanent);

class BoppoEasyPermissions {
  static const MethodChannel _channel =
      const MethodChannel('boppo_easy_permissions/permissions');

  static const MethodChannel _callbackChannel =
      const MethodChannel('boppo_easy_permissions/callback');

  static Set<BoppoEasyPermissions> _callbacks = Set<BoppoEasyPermissions>();

  Granted _granted;
  Denied _denied;
  VoidCallback _onSettingsReturned;

  static Future<bool> has(
      {List<Permissions> perms, List<PermissionGroup> permsGroup}) async {
    assert(perms != null || permsGroup != null);
    try {
      var list = _getPermissionsIndex(Platform.isAndroid ? perms : permsGroup);
      return await _channel.invokeMethod('hasPermissions', {"perms": list});
    } catch (e) {
      debugPrint(e.message);
    }
    return false;
  }

  static void request(
      {List<Permissions> perms,
      List<PermissionGroup> permsGroup,
      String rationale,
      int requestCode = DefaultRequestCode}) async {
    assert(perms != null || permsGroup != null);

    try {
      var list = _getPermissionsIndex(Platform.isAndroid ? perms : permsGroup);
      await _channel.invokeMethod('requestPermissions',
          {"perms": list, "rationale": rationale, "requestCode": requestCode});
    } catch (e) {
      debugPrint(e.message);
    }
  }

  static void openSettings(
      {List<Permissions> perms,
      List<PermissionGroup> permsGroup,
      String rationale,
      int requestCode = DefaultRequestCode}) async {
    assert(perms != null || permsGroup != null);

    try {
      var list = _getPermissionsIndex(Platform.isAndroid ? perms : permsGroup);
      await _channel.invokeMethod('openSettings',
          {"perms": list, "rationale": rationale, "requestCode": requestCode});
    } catch (e) {
      debugPrint(e.message);
    }
  }

  void addPermissionCallback({
    Granted onGranted,
    Denied onDenied,
    VoidCallback onSettingsReturned,
  }) {
    this._granted = onGranted;
    this._denied = onDenied;
    this._onSettingsReturned = onSettingsReturned;
    _callbacks.add(this);
    if (_callbackChannel.checkMethodCallHandler(null)) {
      _callbackChannel.setMethodCallHandler(_handler);
    }
  }

  static Future<dynamic> _handler(MethodCall call) {
    PermissionGroup pg;
    List<Permissions> perms = []..length = 0;
    try {
      switch (call.method) {
        case "onGranted":
          int perm = call.arguments["perm"];
          int requestCode = call.arguments["requestCode"];

          if (perm != null) {
            pg = _getPermission(perm);
          } else {
            List<int> permList = call.arguments["perms"].cast<int>();
            perms = _getPermissions(permList);
          }
          _callbacks.forEach((e) {
            e._granted?.call(requestCode, perms, pg);
          });
          break;
        case "onDenied":
          int perm = call.arguments["perm"];
          int requestCode = call.arguments["requestCode"];
          bool isPermanentlyDenied;
          if (perm != null) {
            pg = _getPermission(perm);
            bool firstTime = call.arguments["firstTime"];
            isPermanentlyDenied = !firstTime;
          } else {
            List<int> permList = call.arguments["perms"].cast<int>();
            isPermanentlyDenied = call.arguments["permanently"];
            perms = _getPermissions(permList);
          }
          _callbacks.forEach((e) {
            e._denied?.call(requestCode, perms, pg, isPermanentlyDenied);
          });
          break;
        case "onSettingsReturned":
          _callbacks.forEach((e) {
            e._onSettingsReturned?.call();
          });
          break;
      }
    } catch (e) {
      debugPrint(e.message);
    }
    return null;
  }

  static List<int> _getPermissionsIndex(List<dynamic> perms) {
    if (perms != null && perms.isNotEmpty) {
      if (perms is List<PermissionGroup>) {
        return perms.map((e) => e.index).toList();
      } else if (perms is List<Permissions>) {
        return perms.map((e) => e.index).toList();
      }
    }
    throw Exception(
        "_getPermissionsIndex: parameter 'perms' cannot be null or empty");
  }

  static List<Permissions> _getPermissions(List<int> perms) {
    if (perms != null && perms.isNotEmpty) {
      return perms.map((e) => Permissions.values[e]).toList();
    }
    throw Exception(
        "_getPermissions: parameter 'perms' cannot be null or empty");
  }

  static PermissionGroup _getPermission(int perm) {
    return PermissionGroup.values[perm];
  }

  static void showAppSettingsDialog(
      {title = SettingsDialogTitle,
      rationale = SettingsDialogRationale,
      positiveButtonText = SettingsDialogPositiveButton,
      negativeButtonText = SettingsDialogNegativeButton}) async {
    try {
      await _channel.invokeMethod('showSettingsDialog', {
        "title": title,
        "rationale": rationale,
        "positiveButtonText": positiveButtonText,
        "negativeButtonText": negativeButtonText
      });
    } catch (e) {
      debugPrint(e.message);
    }
  }

  void dispose() {
    _callbacks.remove(this);
  }
}

// class BoppoEasyPermissions {
//   static const MethodChannel _channel =
//       const MethodChannel('boppo_easy_permissions');
//   static Future<String> get platformVersion async {
//     final String version = await _channel.invokeMethod('getPlatformVersion');
//     return version;
//   }
// }

==> 0.1.3.tar.gz: lib/boppo_easy_permissions.dart <==
import 'dart:async';
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

import 'permission_constants.dart';

///
/// [requestCode] [BoppoEasyPermissions.request]
/// [perms] [BoppoEasyPermissions.request]
/// [permsGroup] [BoppoEasyPermissions.request]
///
typedef Granted = void Function(
    int requestCode, List<Permissions> perms, PermissionGroup perm);

///
/// [isPermanent]
///
typedef Denied = void Function(int requestCode, List<Permissions> perms,
    PermissionGroup perm, bool isPermanent);

class BoppoEasyPermissions {
  static const MethodChannel _channel =
      const MethodChannel('boppo_easy_permissions/permissions');

  static const MethodChannel _callbackChannel =
      const MethodChannel('boppo_easy_permissions/callback');

  static Set<BoppoEasyPermissions> _callbacks = Set<BoppoEasyPermissions>();

  Granted _granted;
  Denied _denied;
  VoidCallback _onSettingsReturned;

  static Future<bool> has(
      {List<Permissions> perms, List<PermissionGroup> permsGroup}) async {
    assert(perms != null || permsGroup != null);
    try {
      var list = _getPermissionsIndex(Platform.isAndroid ? perms : permsGroup);
      return await _channel.invokeMethod('hasPermissions', {"perms": list});
    } catch (e) {
      debugPrint(e.message);
    }
    return false;
  }

  static void request(
      {List<Permissions> perms,
      List<PermissionGroup> permsGroup,
      String rationale,
      int requestCode = DefaultRequestCode}) async {
    assert(perms != null || permsGroup != null);

    try {
      var list = _getPermissionsIndex(Platform.isAndroid ? perms : permsGroup);
      await _channel.invokeMethod('requestPermissions',
          {"perms": list, "rationale": rationale, "requestCode": requestCode});
    } catch (e) {
      debugPrint(e.message);
    }
  }

  static void openSettings() async {
    try {
      await _channel.invokeMethod('openSettings');
    } catch (e) {
      debugPrint(e.message);
    }
  }

  void addPermissionCallback({
    Granted onGranted,
    Denied onDenied,
    VoidCallback onSettingsReturned,
  }) {
    this._granted = onGranted;
    this._denied = onDenied;
    this._onSettingsReturned = onSettingsReturned;
    _callbacks.add(this);
    if (_callbackChannel.checkMethodCallHandler(null)) {
      _callbackChannel.setMethodCallHandler(_handler);
    }
  }

  static Future<dynamic> _handler(MethodCall call) {
    PermissionGroup pg;
    List<Permissions> perms = []..length = 0;
    try {
      switch (call.method) {
        case "onGranted":
          int perm = call.arguments["perm"];
          int requestCode = call.arguments["requestCode"];

          if (perm != null) {
            pg = _getPermission(perm);
          } else {
            List<int> permList = call.arguments["perms"].cast<int>();
            perms = _getPermissions(permList);
          }
          _callbacks.forEach((e) {
            e._granted?.call(requestCode, perms, pg);
          });
          break;
        case "onDenied":
          int perm = call.arguments["perm"];
          int requestCode = call.arguments["requestCode"];
          bool isPermanentlyDenied;
          if (perm != null) {
            pg = _getPermission(perm);
            bool firstTime = call.arguments["firstTime"];
            isPermanentlyDenied = !firstTime;
          } else {
            List<int> permList = call.arguments["perms"].cast<int>();
            isPermanentlyDenied = call.arguments["permanently"];
            perms = _getPermissions(permList);
          }
          _callbacks.forEach((e) {
            e._denied?.call(requestCode, perms, pg, isPermanentlyDenied);
          });
          break;
        case "onSettingsReturned":
          _callbacks.forEach((e) {
            e._onSettingsReturned?.call();
          });
          break;
      }
    } catch (e) {
      debugPrint(e.message);
    }
    return null;
  }

  static List<int> _getPermissionsIndex(List<dynamic> perms) {
    if (perms != null && perms.isNotEmpty) {
      if (perms is List<PermissionGroup>) {
        return perms.map((e) => e.index).toList();
      } else if (perms is List<Permissions>) {
        return perms.map((e) => e.index).toList();
      }
    }
    throw Exception(
        "_getPermissionsIndex: parameter 'perms' cannot be null or empty");
  }

  static List<Permissions> _getPermissions(List<int> perms) {
    if (perms != null && perms.isNotEmpty) {
      return perms.map((e) => Permissions.values[e]).toList();
    }
    throw Exception(
        "_getPermissions: parameter 'perms' cannot be null or empty");
  }

  static PermissionGroup _getPermission(int perm) {
    return PermissionGroup.values[perm];
  }

  static void showAppSettingsDialog(
      {title = SettingsDialogTitle,
      rationale = SettingsDialogRationale,
      positiveButtonText = SettingsDialogPositiveButton,
      negativeButtonText = SettingsDialogNegativeButton}) async {
    try {
      await _channel.invokeMethod('showSettingsDialog', {
        "title": title,
        "rationale": rationale,
        "positiveButtonText": positiveButtonText,
        "negativeButtonText": negativeButtonText
      });
    } catch (e) {
      debugPrint(e.message);
    }
  }

  void dispose() {
    _callbacks.remove(this);
  }
}

// class BoppoEasyPermissions {
//   static const MethodChannel _channel =
//       const MethodChannel('boppo_easy_permissions');
//   static Future<String> get platformVersion async {
//     final String version = await _channel.invokeMethod('getPlatformVersion');
//     return version;
//   }
// }
